# KH2RandomizerGenerator

⚠ Under development! Main branch is not guaranteed to be in a working state! ⚠

This is a fork of [KH2Randomizer](https://github.com/tommadness/KH2Randomizer) for development of a headless version of the seed generator.